@@ -128,6 +128,8 @@ Layer_Freetype::Layer_Freetype()
 
 	SET_INTERPOLATION_DEFAULTS();
 	SET_STATIC_DEFAULTS();
+
+	set_description(param_text.get(String()));
 }
 
 Layer_Freetype::~Layer_Freetype()
@@ -139,6 +141,7 @@ Layer_Freetype::~Layer_Freetype()
 void
 Layer_Freetype::on_canvas_set()
 {
+	Layer_Composite::on_canvas_set();
 	synfig::String family=param_family.get(synfig::String());
 	int style=param_style.get(int());
 	int weight=param_weight.get(int());
@@ -478,7 +481,7 @@ Layer_Freetype::new_face(const String &newfont)
 bool
 Layer_Freetype::set_param(const String & param, const ValueBase &value)
 {
-	Mutex::Lock lock(mutex);
+	std::lock_guard<std::mutex> lock(mutex);
 /*
 	if(param=="font" && value.same_type_as(font))
 	{
@@ -495,7 +498,7 @@ Layer_Freetype::set_param(const String & param, const ValueBase &value)
 			new_font(family,style,weight);
 		}
 		);
-		
+
 	IMPORT_VALUE_PLUS(param_weight,
 		{
 			synfig::String family=param_family.get(synfig::String());
@@ -545,7 +548,7 @@ Layer_Freetype::set_param(const String & param, const ValueBase &value)
 	IMPORT_VALUE_PLUS(param_vcompress,needs_sync_=true);
 	IMPORT_VALUE_PLUS(param_use_kerning,needs_sync_=true);
 	IMPORT_VALUE_PLUS(param_grid_fit,needs_sync_=true);
-	
+
 	if(param=="pos")
 		return set_param("origin", value);
 
@@ -712,7 +715,7 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 	synfig::Point origin=param_origin.get(Point());
 	synfig::Vector orient=param_orient.get(Vector());
 
-	static synfig::RecMutex freetype_mutex;
+	static std::recursive_mutex freetype_mutex;
 
 	if(needs_sync_)
 		const_cast<Layer_Freetype*>(this)->sync();
@@ -759,7 +762,7 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 		return true;
 	}
 
-	synfig::RecMutex::Lock lock(freetype_mutex);
+	std::lock_guard<std::recursive_mutex> lock(freetype_mutex);
 
 #define CHAR_RESOLUTION		(64)
 	error = FT_Set_Char_Size(
@@ -816,27 +819,33 @@ Layer_Freetype::accelerated_render(Context context,Surface *surface,int quality,
 		}
 		else
 		{
-			wchar_t wc;
-			size_t converted = mbrtowc(&wc, &(*iter), text.end() - iter, &ps);
-
-			if(converted == (size_t)(-1))
+			// read uft8 char
+			unsigned int c = (unsigned char)*iter;
+			unsigned int code = c;
+			int bytes = 0;
+			while ((c & 0x80) != 0) { c = (c << 1) & 0xff; bytes++; }
+			bool bad_char = (bytes == 1);
+			if (bytes > 1)
 			{
-				synfig::warning("Layer_Freetype: multibyte: %s",
-								_("Invalid multibyte sequence - is the locale set?\n"));
-				continue;
+				bytes--;
+				code = c << (5*bytes - 1);
+				while (bytes > 0) {
+					iter++;
+					bytes--;
+					c = (unsigned char)*iter;
+					if (iter >= text.end() || (c & 0xc0) != 0x80) { bad_char = true; break; }
+					code |= (c & 0x3f) << (6 * bytes);
+				}
 			}
 
-			if(converted == (size_t)(-2))
+			if (bad_char)
 			{
 				synfig::warning("Layer_Freetype: multibyte: %s",
 								_("Can't parse multibyte character.\n"));
 				continue;
 			}
 
-			glyph_index = FT_Get_Char_Index( face, wc );
-
-			if(converted > 1)
-				iter += converted - 1;
+			glyph_index = FT_Get_Char_Index( face, code );
 		}
 
         // retrieve kerning distance and move pen position
@@ -1018,7 +1027,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	synfig::Vector orient=param_orient.get(Vector());
 	synfig::String font=param_font.get(synfig::String());
 	synfig::String text=param_text.get(synfig::String());
-	
+
 	if(!is_solid_color())
 	{
 		// Initially render what's behind us
@@ -1028,9 +1037,9 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 			return false;
 		}
 	}
-	
+
 	RendDesc workdesc(renddesc);
-	
+
 	// Untransform the render desc
 	if(!cairo_renddesc_untransform(cr, workdesc))
 		return false;
@@ -1046,7 +1055,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	const double wsy=1/wph;
 	const double wtx=(-wtlx+origin[0])*wsx;
 	const double wty=(-wtly+origin[1])*wsy;
-	
+
 	// Cairo context
 	cairo_surface_t* subimage = NULL;
 	cairo_surface_t* inverted = NULL;
@@ -1060,7 +1069,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 		cairo_set_source_rgba(invertcr, color.get_r(), color.get_g(), color.get_b(), color.get_a());
 		cairo_paint_with_alpha(invertcr, get_amount());
 	}
-	
+
 	// Pango
 	PangoLayout *layout;
 	PangoFontDescription *font_description;
@@ -1074,10 +1083,10 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	Real sizey=1.75*fabs(size[1])*fabs(wsy);
 	Real vscale=sizey/sizex;
 	pango_font_description_set_absolute_size (font_description, sizex * PANGO_SCALE );
-	
+
 	//Pango Layout
 	layout = pango_cairo_create_layout (subcr);
-	
+
 	pango_layout_set_font_description (layout, font_description);
 	pango_layout_set_text (layout, text.c_str(), -1);
 	if(orient[0]<0.4)
@@ -1086,14 +1095,14 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 		pango_layout_set_alignment(layout, PANGO_ALIGN_RIGHT);
 	else
 		pango_layout_set_alignment(layout, PANGO_ALIGN_CENTER);
-	
+
 	pango_layout_set_single_paragraph_mode(layout, false);
-	
+
 	// Calculate the logical and ink rectangles of the layout before add spacing
 	PangoRectangle ink_layout, logical_layout;
 	PangoRectangle ink_rect, logical_rect;
 	pango_layout_get_pixel_extents(layout, &ink_layout, &logical_layout);
-	
+
 	// Spacing
 	// Horizontal
 	PangoAttrList* attrlist=pango_attr_list_new();
@@ -1101,7 +1110,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	PangoAttribute* spacing=pango_attr_letter_spacing_new(hspace*PANGO_SCALE);
 	pango_attr_list_insert_before(attrlist, spacing);
 	pango_layout_set_attributes(layout, attrlist);
-	
+
 	// Vertical
 	int total_lines=pango_layout_get_line_count(layout);
 	Real vspace_total=vcompress>1.0?0.4*logical_layout.height*(vcompress-1.0):(vcompress<1.0)?0.6*logical_layout.height*(vcompress-1.0):0;
@@ -1109,10 +1118,10 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	if(total_lines>1)
 		vspace=vspace_total/(total_lines-1);
 	pango_layout_set_spacing(layout, vspace*PANGO_SCALE);
-	
+
 	// Recalculate extents due to spacing changes
 	pango_layout_get_pixel_extents(layout, &ink_layout, &logical_layout);
-	
+
 	// Render text
 	cairo_save(subcr);
 	cairo_set_source_rgba(subcr, color.get_r(), color.get_g(), color.get_b(), color.get_a());
@@ -1120,7 +1129,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 	pango_cairo_update_layout(subcr, layout);
 	cairo_move_to(subcr, wtx-logical_layout.width*orient[0], (wty-(logical_layout.height+vspace_total)*vscale*orient[1])/vscale);
 	pango_cairo_show_layout(subcr, layout);
-	
+
 	// Debug ink and logical lines
 	if(0)
 	{
@@ -1135,7 +1144,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 						ink_rect.height);
 		cairo_stroke(subcr);
 		cairo_restore(subcr);
-		
+
 		cairo_save(subcr);
 		cairo_set_line_width(subcr, 1.0);
 		cairo_set_source_rgb(subcr, 0.0, 0.0, 1.0);
@@ -1150,7 +1159,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 		cairo_restore(subcr);
 	}
 	cairo_restore(subcr);
-	
+
 	cairo_save(cr);
 	// Render the text on the target surface with the proper operator
 	if(invert)
@@ -1176,7 +1185,7 @@ Layer_Freetype::accelerated_cairorender(Context context, cairo_t *cr, int qualit
 		cairo_paint_with_alpha_operator(cr, get_amount(), get_blend_method());
 	}
 	cairo_restore(cr);
-	
+
 	// Destroy and return
 	cairo_surface_destroy(subimage);
 	cairo_destroy(subcr);
