@@ -46,7 +46,7 @@ using namespace synfig;
 
 //PARSER PREFERENCES
 
-//Seperate transformations: apply transformations on a per-layer basis, rather than on canvases
+//Separate transformations: apply transformations on a per-layer basis, rather than on canvases
 #define SVG_SEP_TRANSFORMS 1
 
 //Resolve BLine transformations: resolve transformations instead of creating transformation layers
@@ -97,7 +97,8 @@ Svg_parser::load_svg_canvas(std::string _filepath,String &errors, String &warnin
 	return canvas;
 }
 
-Svg_parser::Svg_parser():
+Svg_parser::Svg_parser(const Gamma &gamma):
+	gamma(gamma),
 	nodeRoot(NULL),
 	uid(0),
 	kux(60),
@@ -105,8 +106,6 @@ Svg_parser::Svg_parser():
 	ox(0),
 	oy(0)
 {
-	// 0.5 in gamma parameter of color correct layer is 1/0.5 = 2 (thinking) it must be 2.2!!!!
-	gamma.set_gamma(2.2);
 }
 /*
 String
@@ -252,6 +251,7 @@ Svg_parser::parser_graphics(const xmlpp::Node* node,xmlpp::Element* root,String
 		}
 		if(nodename.compare("g")==0){
 			parser_layer (node,root->add_child("layer"),parent_style,mtx);
+			free(mtx);
 			return;
 		}
 
@@ -302,6 +302,7 @@ Svg_parser::parser_graphics(const xmlpp::Node* node,xmlpp::Element* root,String
 				build_fill (child_fill,fill,NULL);
 			}
 			parser_effects(nodeElement,child_layer,parent_style,mtx);
+			free(mtx);
 			return;
 		}
 		if ((!(SVG_RESOLVE_BLINE) && mtx) || typeFill==2 || typeStroke==2)
@@ -416,6 +417,7 @@ Svg_parser::parser_graphics(const xmlpp::Node* node,xmlpp::Element* root,String
 			parser_effects(nodeElement,child_layer,parent_style,NULL);
 		else
 			parser_effects(nodeElement,child_layer,parent_style,mtx);
+		free(mtx);
 	}
 }
 
@@ -1018,7 +1020,7 @@ Svg_parser::build_linearGradient(xmlpp::Element* root,LinearGradient* data,SVGMa
 				mtx2=data->transform;
 			}
 			//matrix transforms the gradient as a whole
-			//it does not preserve angles, so we cant' simply transform both points
+			//it does not preserve angles, so we can't simply transform both points
 			float x3, y3, k;
 			//set point (x3,y3) on the same gradient line as (x2,y2)
 			//the gradient line is perpendicular to (x1,y1)(x2,y2)
@@ -1203,7 +1205,7 @@ Svg_parser::parser_radialGradient(const xmlpp::Node* node){
 
 		std::list<ColorStop*> *stops=NULL;
 		if(!link.empty()){
-			//inkscape always use link, i dont need parser stops here, but it's posible
+			//inkscape always use link, i don't need parser stops here, but it's possible
 			stops=find_colorStop (link);
 		}
 		if(stops)
@@ -1227,28 +1229,10 @@ Svg_parser::newColorStop(String color,float opacity,float pos){
 	_stop->pos=pos;
 	return _stop;
 }
+
 Color
 Svg_parser::adjustGamma(float r,float g,float b,float a){
-	Color ret(r,g,b,a);
-	if(gamma.get_gamma_r()!=1.0){
-		if(ret.get_r() < 0)
-			ret.set_r(-gamma.r_F32_to_F32(-ret.get_r()));
-		else
-			ret.set_r(gamma.r_F32_to_F32(ret.get_r()));
-	}
-	if(gamma.get_gamma_g()!=1.0){
-		if(ret.get_g() < 0)
-			ret.set_g(-gamma.g_F32_to_F32(-ret.get_g()));
-		else
-			ret.set_g(gamma.g_F32_to_F32(ret.get_g()));
-	}
-	if(gamma.get_gamma_b()!=1.0){
-		if(ret.get_b() < 0)
-			ret.set_b(-gamma.b_F32_to_F32(-ret.get_b()));
-		else
-			ret.set_b(gamma.b_F32_to_F32(ret.get_b()));
-	}
-	return ret;
+	return gamma.apply(Color(r,g,b,a));
 }
 
 LinearGradient*
@@ -1633,6 +1617,8 @@ Svg_parser::parser_transform(const String transform){
 			else
 				multiplySVGMatrix(&a,newSVGMatrix((*aux).substr(start,end-start)));
 		}else{
+			if (!matrixIsNull(a))
+				free(a);
 			a=newSVGMatrix(1,0,0,1,0,0);
 		}
 		aux++;
@@ -1675,11 +1661,8 @@ Svg_parser::newSVGMatrix(const String mvector){
 }
 void
 Svg_parser::transformPoint2D(SVGMatrix *mtx,float *a,float *b){
-	float auxa,auxb;
-	auxa=0;
-	auxb=0;
-	auxa= (*a)*(mtx->a) + (*b)*(mtx->c) + (mtx->e);
-	auxb= (*a)*(mtx->b) + (*b)*(mtx->d) + (mtx->f);
+	float auxa= (*a)*(mtx->a) + (*b)*(mtx->c) + (mtx->e);
+	float auxb= (*a)*(mtx->b) + (*b)*(mtx->d) + (mtx->f);
 	*a=auxa;
 	*b=auxb;
 	return;
@@ -1710,6 +1693,7 @@ Svg_parser::multiplySVGMatrix(SVGMatrix **mtx1,SVGMatrix *mtx2){
 	(*mtx1)->d=aux->d;
 	(*mtx1)->e=aux->e;
 	(*mtx1)->f=aux->f;
+	free(aux);
 }
 bool
 Svg_parser::matrixIsNull(SVGMatrix *mtx){
@@ -1801,6 +1785,10 @@ Svg_parser::get_tokens_path(String path){ //mini path lexico-parser
 					else if(a=='-' || a=='.' || a=='e' || a=='E' || isdigit (a)){ e=18;}
 					else if(a==','){ e=19; i++;}
 					else if(a==' '){i++;}
+					else {
+						synfig::warning("unknown token in SVG path '%c'", a);
+						i++;
+					}
 					break;
 			//relative
 			case 1 : tokens.push_back("m"); e=0; break;//move
