@@ -31,10 +31,6 @@
 #	include <config.h>
 #endif
 
-#ifdef HAVE_SYS_ERRNO_H
-#	include <sys/errno.h>
-#endif
-
 #include "savecanvas.h"
 #include "general.h"
 #include <synfig/localization.h>
@@ -69,11 +65,10 @@
 #include <libxml++/libxml++.h>
 #include <ETL/stringf>
 #include "gradient.h"
-#include <errno.h>
 
-extern "C" {
+/*extern "C" {
 #include <libxml/tree.h>
-}
+}*/
 
 #endif
 
@@ -584,10 +579,16 @@ xmlpp::Element* encode_dynamic_list(xmlpp::Element* root,ValueNode_DynamicList::
 	ValueNode_WPList::ConstHandle wplist_value_node(ValueNode_WPList::ConstHandle::cast_dynamic(value_node));
 	ValueNode_DIList::ConstHandle dilist_value_node(ValueNode_DIList::ConstHandle::cast_dynamic(value_node));
 
+	bool must_rotate_point_list = false;
+
 	if(bline_value_node)
 	{
 		if(bline_value_node->get_loop())
+		{
 			root->set_attribute("loop","true");
+			if (save_canvas_version < RELEASE_VERSION_1_4_0) // or get_file_version()?
+				must_rotate_point_list = true;
+		}
 		else
 			root->set_attribute("loop","false");
 	}
@@ -606,7 +607,19 @@ xmlpp::Element* encode_dynamic_list(xmlpp::Element* root,ValueNode_DynamicList::
 			root->set_attribute("loop","false");
 	}
 
-	for(iter=value_node->list.begin();iter!=value_node->list.end();++iter)
+	std::vector<ValueNode_DynamicList::ListEntry> corrected_valuenode_list = value_node->list;
+
+	if (must_rotate_point_list) {
+		if (must_rotate_point_list) {
+			if (corrected_valuenode_list.size() > 0) {
+				auto node = corrected_valuenode_list.front();
+				corrected_valuenode_list.push_back(node);
+				corrected_valuenode_list.erase(corrected_valuenode_list.begin());
+			}
+		}
+	}
+
+	for(iter=corrected_valuenode_list.begin();iter!=corrected_valuenode_list.end();++iter)
 	{
 		xmlpp::Element	*entry_node=root->add_child("entry");
 		assert(iter->value_node);
@@ -937,23 +950,34 @@ xmlpp::Element* encode_canvas(xmlpp::Element* root,Canvas::ConstHandle canvas)
 	root->set_name("canvas");
 
 	if(canvas->is_root())
-		root->set_attribute("version",canvas->get_version());
+	{
+		if (save_canvas_version < RELEASE_VERSION_1_4_0)
+			root->set_attribute("version","1.0");
+		else
+			root->set_attribute("version",canvas->get_version());
+	}
 
 	if(!canvas->get_id().empty() && !canvas->is_root() && !canvas->is_inline())
 		root->set_attribute("id",canvas->get_id());
 
-	if(!canvas->parent() || canvas->parent()->rend_desc().get_w()!=canvas->rend_desc().get_w())
+	if(!canvas->parent() || canvas->parent()->rend_desc().get_w()!=rend_desc.get_w())
 		root->set_attribute("width",strprintf("%d",rend_desc.get_w()));
 
-	if(!canvas->parent() || canvas->parent()->rend_desc().get_h()!=canvas->rend_desc().get_h())
+	if(!canvas->parent() || canvas->parent()->rend_desc().get_h()!=rend_desc.get_h())
 		root->set_attribute("height",strprintf("%d",rend_desc.get_h()));
 
-	if(!canvas->parent() || canvas->parent()->rend_desc().get_x_res()!=canvas->rend_desc().get_x_res())
+	if(!canvas->parent() || canvas->parent()->rend_desc().get_x_res()!=rend_desc.get_x_res())
 		root->set_attribute("xres",strprintf("%f",rend_desc.get_x_res()));
 
-	if(!canvas->parent() || canvas->parent()->rend_desc().get_y_res()!=canvas->rend_desc().get_y_res())
+	if(!canvas->parent() || canvas->parent()->rend_desc().get_y_res()!=rend_desc.get_y_res())
 		root->set_attribute("yres",strprintf("%f",rend_desc.get_y_res()));
 
+	if(!canvas->parent() || canvas->parent()->rend_desc().get_gamma()!=rend_desc.get_gamma())
+	{
+		root->set_attribute("gamma-r",strprintf("%f",rend_desc.get_gamma().get_r()));
+		root->set_attribute("gamma-g",strprintf("%f",rend_desc.get_gamma().get_g()));
+		root->set_attribute("gamma-b",strprintf("%f",rend_desc.get_gamma().get_b()));
+	}
 
 	if(!canvas->parent() ||
 		canvas->parent()->rend_desc().get_tl()!=canvas->rend_desc().get_tl() ||
@@ -977,6 +1001,9 @@ xmlpp::Element* encode_canvas(xmlpp::Element* root,Canvas::ConstHandle canvas)
 	if(!canvas->parent() || canvas->parent()->rend_desc().get_time_end()!=canvas->rend_desc().get_time_end())
 		root->set_attribute("end-time",rend_desc.get_time_end().get_string(rend_desc.get_frame_rate()));
 
+	if(!canvas->parent() || canvas->parent()->rend_desc().get_gamma()!=canvas->rend_desc().get_gamma())
+		root->set_attribute("end-time",rend_desc.get_time_end().get_string(rend_desc.get_frame_rate()));
+
 	if(!canvas->is_inline())
 	{
 		root->set_attribute("bgcolor",strprintf(VIEW_BOX_FORMAT,
