@@ -1,13 +1,12 @@
 /* === S Y N F I G ========================================================= */
 /*!	\file valuenode.h
-**	\brief Header file for implementation of the "Placeholder" valuenode conversion.
-**
-**	$Id$
+**	\brief Valuenodes
 **
 **	\legal
 **	Copyright (c) 2002-2005 Robert B. Quattlebaum Jr., Adrian Bentley
 **	Copyright (c) 2008 Chris Moore
-**  Copyright (c) 2011 Carlos López
+**	Copyright (c) 2011 Carlos López
+**	Copyright (c) 2016 caryoscelus
 **
 **	This package is free software; you can redistribute it and/or
 **	modify it under the terms of the GNU General Public License as
@@ -33,19 +32,21 @@
 #include "value.h"
 #include "string.h"
 #include "releases.h"
-#include <ETL/handle>
-#include <ETL/stringf>
 #include "exception.h"
-#include <map>
-#include <sigc++/signal.h>
 #include "guid.h"
-#include <ETL/angle>
 #include "paramdesc.h"
 #include "interpolation.h"
-
 #include "node.h"
 
+#include <ETL/angle>
+#include <ETL/handle>
+#include <ETL/stringf>
+
+#include <sigc++/signal.h>
+
+#include <map>
 #include <set>
+#include <memory>
 
 /* === M A C R O S ========================================================= */
 
@@ -95,6 +96,7 @@ class ValueNode : public synfig::Node
 {
 	friend class Layer;
 	friend class LinkableValueNode;
+	friend class ValueNode_Interface;
 
 	/*
  --	** -- T Y P E S -----------------------------------------------------------
@@ -110,11 +112,6 @@ public:
 
 	typedef etl::rhandle<ValueNode> RHandle;
 
-	//!Instantiates the book of ValaueNodes and register all the valid valuenodes on it
-	static bool subsys_init();
-	//!Deletes the book of ValueNodes
-	static bool subsys_stop();
-
 	static void breakpoint();
 
 	/*
@@ -228,6 +225,9 @@ public:
 	//! Returns \true if the Value Node has an ID (has been exported)
 	bool is_exported()const { return !get_id().empty(); }
 
+	//! Check recursively if \value_node_dest is a descendant of the Value Node
+	bool is_descendant(ValueNode::Handle value_node_dest);
+
 	//! Returns the type of the ValueNode
 	Type& get_type()const { return *type; }
 
@@ -256,19 +256,62 @@ public:
 	//! \see etl::rhandle
 	int replace(etl::handle<ValueNode> x);
 	
-	//! Get/Set the default interpolation for Value Nodes
+	//! Get the default interpolation for Value Nodes
 	virtual Interpolation get_interpolation()const { return INTERPOLATION_UNDEFINED; }
+	//! Set the default interpolation for Value Nodes
 	virtual void set_interpolation(Interpolation /* i*/) { }
 
+	// TODO: cache of values (we need to fix chain of signals 'changed' in LinkableValueNodes
+	void get_values(std::set<ValueBase> &x) const;
+	void get_value_change_times(std::set<Time> &x) const;
+	void get_values(std::map<Time, ValueBase> &x) const;
+
+	void calc_time_bounds(int &begin, int &end, Real &fps) const;
+	void calc_values(std::map<Time, ValueBase> &x) const;
+	void calc_values(std::map<Time, ValueBase> &x, int begin, int end) const;
+	void calc_values(std::map<Time, ValueBase> &x, int begin, int end, Real fps) const;
+
+	int time_to_frame(Time t);
+	static int time_to_frame(Time t, Real fps);
+	static void add_value_to_map(std::map<Time, ValueBase> &x, Time t, const ValueBase &v);
+
+private:
+	static void canvas_time_bounds(const Canvas &canvas, bool &found, Time &begin, Time &end, Real &fps);
+	static void find_time_bounds(const Node &node, bool &found, Time &begin, Time &end, Real &fps);
+
 protected:
 	//! Sets the type of the ValueNode
 	void set_type(Type &t) { type=&t; }
 
 	virtual void on_changed();
+
+	virtual void get_values_vfunc(std::map<Time, ValueBase> &x) const;
 }; // END of class ValueNode
 
+
+
+/**	\class ValueNode_Interface */
+class ValueNode_Interface
+{
+private:
+	ValueNode &node_;
+
+protected:
+	explicit ValueNode_Interface(ValueNode &node): node_(node) { }
+
+public:
+	virtual ~ValueNode_Interface() { }
+	ValueNode& node() { return node_; };
+	const ValueNode& node() const { return node_; };
+
+protected:
+	void set_type(Type &t) { node().set_type(t); }
+};
+
+
+
 /*!	\class PlaceholderValueNode
-**	Seems to be a Place to hold a Value Node temporarly.
+**	Seems to be a Place to hold a Value Node temporarily.
 *
 * 	Doesn't seem to implement any functionality. Seems to be used when the
 * 	value node cannot be created using the Const, Animated or Linkable
@@ -327,52 +370,11 @@ public:
 
 	typedef etl::rhandle<LinkableValueNode> RHandle;
 
-
-	//! Type that represents a pointer to a ValueNode's constructor
-	/*! As a pointer to the constructor, it represents a "factory" of
-	**  objects of this class.
-	*/
-	typedef LinkableValueNode* (*Factory)(const ValueBase&, etl::loose_handle<Canvas> canvas);
-
-	//! This represents a pointer to a Type check member fucntion
-	/*! As a pointer to the member, it represents a fucntion that checks
-	**  the type of the provided ValueBase
-	*/
-	typedef bool (*CheckType)(Type &type);
-
-	struct BookEntry
-	{
-		String local_name;
-		Factory factory;
-		CheckType check_type;
-		ReleaseVersion release_version; // which version of synfig introduced this valuenode type
-	};
-
-	//! Book of types of linkable value nodes indexed by type name.
-	/*! While the sifz file is read, each time a new LinkableValueNode entry
-	**  is found, the factory constructor that the "factory" pointer member
-	**  of the "BookEntry" struct points to, is called, and a new object of
-	**  that type is created.
-	**  \sa LinkableValueNode::Factory
-	*/
-	typedef std::map<String,BookEntry> Book;
-
 	//! The vocabulary of the children
 	/*! \see synfig::Paramdesc
 	 */
 	typedef ParamVocab Vocab;
 
-	static Book& book();
-
-	//! Creates a Linkable Value Node based on the name and the returned
-	//! value type. Returns a valid Handle if both (name and type) match
-	static Handle create(const String &name, const ValueBase& x, etl::loose_handle<Canvas> canvas /* = 0 */);
-
-	//! Each derived Linkable Value Node has to implement this fucntion and
-	//! should return true only if the type matches. \name is the name of
-	//! the linked value node and \x is the returned value type
-	static bool check_type(const String &name, Type &x);
-
 public:
 	LinkableValueNode(Type &type=type_nil):
 		ValueNode(type) { }
@@ -442,8 +444,10 @@ protected:
 	//! Pure Virtual member to get the children vocabulary
 	virtual Vocab get_children_vocab_vfunc()const=0;
 
-	//! Virtual memebr to set the children vocabulary to a given value
+	//! Virtual member to set the children vocabulary to a given value
 	virtual void set_children_vocab(const Vocab& rvocab);
+
+	virtual void get_values_vfunc(std::map<Time, ValueBase> &x) const;
 }; // END of class LinkableValueNode
 
 /*!	\class ValueNodeList
