@@ -37,6 +37,7 @@
 #include <stdexcept>
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 #include "valuenode_radialcomposite.h"
 #include <synfig/vector.h>
 #include <synfig/color.h>
@@ -61,6 +62,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_Composite, RELEASE_VERSION_0_61_06, "composite", "Composite")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -379,7 +382,7 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 			{
 				if(i==4 && components[5])
 				{
-					if(i==4 && (*x)(0).get(Real()) < (*components[5])(0).get(Real()))
+					if ((*x)(0).get(Real()) < (*components[5])(0).get(Real()))
 					{
 						components[i]=x;
 						return true;
@@ -387,9 +390,9 @@ ValueNode_Composite::set_link_vfunc(int i,ValueNode::Handle x)
 					else
 						return false;
 				}
-				if(i==5 && components[4])
+				if (i==5 && components[4])
 				{
-					if((i==5 && (*x)(0).get(Real()) > (*components[4])(0).get(Real())))
+					if ((*x)(0).get(Real()) > (*components[4])(0).get(Real()))
 					{
 						components[i]=x;
 						return true;
@@ -592,17 +595,7 @@ ValueNode_Composite::get_link_index_from_name(const String &name)const
 	throw Exception::BadLinkName(name);
 }
 
-String
-ValueNode_Composite::get_name()const
-{
-	return "composite";
-}
 
-String
-ValueNode_Composite::get_local_name()const
-{
-	return _("Composite");
-}
 
 bool
 ValueNode_Composite::check_type(Type &type)
@@ -739,6 +732,8 @@ ValueNode_Composite::get_children_vocab_vfunc()const
 			.add_enum_value(WidthPoint::TYPE_SQUARED,"squared", _("Squared Stop"))
 			.add_enum_value(WidthPoint::TYPE_PEAK,"peak", _("Peak Stop"))
 			.add_enum_value(WidthPoint::TYPE_FLAT,"flat", _("Flat Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_ROUNDED,"inner_rounded", _("Inner Rounded Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_PEAK,"inner_peak", _("Off-Peak Stop"))
 			);
 		ret.push_back(ParamDesc(ValueBase(),"side_after")
 			.set_local_name(_("Side Type After"))
@@ -749,6 +744,8 @@ ValueNode_Composite::get_children_vocab_vfunc()const
 			.add_enum_value(WidthPoint::TYPE_SQUARED,"squared", _("Squared Stop"))
 			.add_enum_value(WidthPoint::TYPE_PEAK,"peak", _("Peak Stop"))
 			.add_enum_value(WidthPoint::TYPE_FLAT,"flat", _("Flat Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_ROUNDED,"inner_rounded", _("Inner Rounded Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_PEAK,"inner_peak", _("Off-Peak Stop"))
 		);
 		ret.push_back(ParamDesc(ValueBase(),"lower_bound")
 			.set_local_name(_("Lower Boundary"))
@@ -766,12 +763,10 @@ ValueNode_Composite::get_children_vocab_vfunc()const
 		ret.push_back(ParamDesc(ValueBase(),"offset")
 			.set_local_name(_("Offset"))
 			.set_description(_("The offset length of the Dash Item over the Spline"))
-			.set_is_distance()
 		);
 		ret.push_back(ParamDesc(ValueBase(),"length")
 			.set_local_name(_("Length"))
 			.set_description(_("The length of the Dash Item"))
-			.set_is_distance()
 		);
 		ret.push_back(ParamDesc(ValueBase(),"side_before")
 			.set_local_name(_("Side Type Before"))
@@ -781,6 +776,8 @@ ValueNode_Composite::get_children_vocab_vfunc()const
 			.add_enum_value(WidthPoint::TYPE_SQUARED,"squared", _("Squared Stop"))
 			.add_enum_value(WidthPoint::TYPE_PEAK,"peak", _("Peak Stop"))
 			.add_enum_value(WidthPoint::TYPE_FLAT,"flat", _("Flat Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_ROUNDED,"inner_rounded", _("Inner Rounded Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_PEAK,"inner_peak", _("Off-Peak Stop"))
 			);
 		ret.push_back(ParamDesc(ValueBase(),"side_after")
 			.set_local_name(_("Side Type After"))
@@ -790,6 +787,8 @@ ValueNode_Composite::get_children_vocab_vfunc()const
 			.add_enum_value(WidthPoint::TYPE_SQUARED,"squared", _("Squared Stop"))
 			.add_enum_value(WidthPoint::TYPE_PEAK,"peak", _("Peak Stop"))
 			.add_enum_value(WidthPoint::TYPE_FLAT,"flat", _("Flat Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_ROUNDED,"inner_rounded", _("Inner Rounded Stop"))
+			.add_enum_value(WidthPoint::TYPE_INNER_PEAK,"inner_peak", _("Off-Peak Stop"))
 		);
 		return ret;
 	}
